Summary:   Portable Hardware Locality - portable abstraction of hierarchical architectures
Name:      hwloc
Version:   2.9.2
Release:   4%{?dist}
License:   BSD
%define maj_ver %(echo %{version} | cut -d. -f1)
%define min_ver %(echo %{version} | cut -d. -f2)
URL:       https://www.open-mpi.org/projects/hwloc/
Source0:   https://download.open-mpi.org/release/hwloc/v%{maj_ver}.%{min_ver}/%{name}-%{version}.tar.bz2

BuildRequires: make gcc gcc-c++
BuildRequires: cairo-devel libpciaccess-devel
BuildRequires: libX11-devel libxml2-devel ncurses-devel
BuildRequires: doxygen lynx
BuildRequires: desktop-file-utils
BuildRequires: numactl-devel rdma-core-devel
%ifarch x86_64
%{?systemd_requires}
BuildRequires: systemd
%endif
Requires:  %{name}-libs = %{version}-%{release}

%description
The Portable Hardware Locality (hwloc) software package provides command line tools and a 
powerful programming interface (C API)  to obtain the hierarchical map of key computing 
elements, such as: NUMA memory nodes, shared caches, processor sockets, processor cores 
and processing units (logical processors or "threads").
It also gathers various system attributes such as cache and memory information，and is 
portable across a variety of different operating systems and platforms.

%package devel
Summary:   Headers and shared development libraries for hwloc
Requires:  %{name}-libs = %{version}-%{release}
Requires:  rdma-core-devel

%description devel
This package contains headers and shared object symbolic links for the hwloc.

%package libs
Summary:   Run time libraries for the hwloc

%description libs
This package provides run time libraries for the hwloc

%package gui
Summary:   The gui-based hwloc program(s)
Requires:  %{name}-libs = %{version}-%{release}

%description gui
GUI-based tool for displaying system topology information.

%package plugins
Summary:   Plugins for hwloc
Requires:  %{name}-plugins = %{version}-%{release}

%description plugins
This package contains plugins for hwloc. It includes PCI support, GL support, libxml support.

%prep
%autosetup

%build
export runstatedir=/run
%configure --enable-plugins --disable-silent-rules
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'

cp -p AUTHORS COPYING NEWS README VERSION %{buildroot}%{_pkgdocdir}
cp -pr doc/examples %{buildroot}%{_pkgdocdir}
mv  %{buildroot}%{_pkgdocdir}/examples/Makefile  %{buildroot}%{_pkgdocdir}/examples/Makefile_%{_arch}

desktop-file-validate %{buildroot}/%{_datadir}/applications/lstopo.desktop

rm %{buildroot}%{_mandir}/man1/lstopo.1
ln %{buildroot}%{_mandir}/man1/lstopo-no-graphics.1 %{buildroot}%{_mandir}/man1/lstopo.1

# Deal with service files https://github.com/open-mpi/hwloc/issues/221
%ifarch x86_64
mkdir -p %{buildroot}%{_unitdir}
mv %{buildroot}%{_datadir}/%{name}/hwloc-dump-hwdata.service %{buildroot}%{_unitdir}/
%else
rm %{buildroot}%{_datadir}/%{name}/hwloc-dump-hwdata.service
%endif

%check
LD_LIBRARY_PATH=$PWD/hwloc/.libs make check

%ifarch x86_64
%post
%systemd_post hwloc-dump-hwdata.service

%preun
%systemd_preun hwloc-dump-hwdata.service

%postun
%systemd_postun_with_restart hwloc-dump-hwdata.service
%endif

%files
%{_bindir}/%{name}*
%{_bindir}/lstopo-no-graphics
%ifarch x86_64
%{_sbindir}/hwloc-dump-hwdata
%{_unitdir}/hwloc-dump-hwdata.service
%endif
%{_datadir}/hwloc/hwloc-ps.www/
%{_datadir}/bash-completion/completions/*
%{_mandir}/man1/%{name}*
%{_mandir}/man1/lstopo-no-graphics*

%files devel
%{_libdir}/pkgconfig/*
%{_libdir}/*.so
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*
%{_includedir}/%{name}.h
%{_pkgdocdir}/examples
%{_mandir}/man3/*

%files libs
%{_libdir}/libhwloc*so.15*
%dir %{_datadir}/%{name}
%{_datadir}/hwloc/hwloc.dtd
%{_datadir}/hwloc/hwloc-valgrind.supp
%{_datadir}/hwloc/hwloc2.dtd
%{_datadir}/hwloc/hwloc2-diff.dtd
%dir %{_pkgdocdir}/
%{_pkgdocdir}/*[^c]
%{_mandir}/man7/%{name}*

%files gui
%{_bindir}/lstopo
%{_datadir}/applications/lstopo.desktop
%{_mandir}/man1/lstopo.1*

%files plugins
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/hwloc*

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.9.2-4
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.9.2-3
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.9.2-2
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Aug 17 2023 kianli <kianli@tencent.com> - 2.9.2-1
- Upgrade to 2.9.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.0-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.0-3
- Rebuilt for OpenCloudOS Stream 23

* Mon Feb 20 2023 Shuo Wang <abushwang@tencent.com> - 2.5.0-2
- remove unused buildrequires

* Wed Nov 16 2022 Wang Guodong <gordonwwang@tencent.com> - 2.5.0-1
- package init.
